@@ -10,15 +10,15 @@ dodata <- function(method) {
 
     data(hemophilia);   show(QdaCov(as.factor(gr)~., data=hemophilia, method=method))
     data(anorexia, package="MASS");     show(QdaCov(Treat~., data=anorexia, method=method))
-    data(Pima.tr, package="MASS");      # show(QdaCov(type~., data=Pima.tr, method=method))
+    data(Pima.tr, package="MASS");      show(QdaCov(type~., data=Pima.tr, method=method))
     data(iris);                         # show(QdaCov(Species~., data=iris, method=method))
-    data(crabs, package="MASS");        show(QdaCov(sp~., data=crabs, method=method))
-    
+    data(crabs, package="MASS");        # show(QdaCov(sp~., data=crabs, method=method))
+
     show(QdaClassic(as.factor(gr)~., data=hemophilia))
     show(QdaClassic(Treat~., data=anorexia))
     show(QdaClassic(type~., data=Pima.tr))
     show(QdaClassic(Species~., data=iris))
-    show(QdaClassic(sp~., data=crabs))
+##    show(QdaClassic(sp~., data=crabs))
     cat("===================================================\n")
 }
 
